SummScreen Summarization dataset, non-anonymized, non-tokenized version.

Train/val/test splits and filtering are based on the final tokenized dataset,
but transcripts and recaps provided are based on the untokenized text.

There are two features:

-   transcript: Full episode transcripts, each line of dialogue separated by
    newlines
-   recap: Recaps or summaries of episodes
